pub const SEQ_OUTPUT_FMT_ERR: &str = "Invalid output format. \
    Valid options: 'fasta', \
    'nexus', 'phylip',\
    'fast-int', 'nexus-int', 'phylip-int'";

pub const SEQ_INPUT_FMT_ERR: &str =
    "Invalid input format. Valid options: 'fasta', 'nexus', 'phylip'";
pub const SEQ_DATA_TYPE_ERR: &str = "Invalid data type. Valid options: 'dna', 'aa', 'ignore'";
